#--------------------------------------------------------------------------------------
# Detection In stochastic environments - code to estimate detection and produce figures
#--------------------------------------------------------------------------------------
library(matrixStats)
load(file = "supp_1.RData")


# extract detection probs from original occuapncy study
Pstar1 <- array(NA, dim = c(dat$n.sims, 20))
Pstar2 <- array(NA, dim = c(dat$n.sims, 20))
Pstar3 <- array(NA, dim = c(dat$n.sims, 20))
Pstar4 <- array(NA, dim = c(dat$n.sims, 20))
Pstar5 <- array(NA, dim = c(dat$n.sims, 20))
Pstar6 <- array(NA, dim = c(dat$n.sims, 20))
Pstar7 <- array(NA, dim = c(dat$n.sims, 20))
Pstar8 <- array(NA, dim = c(dat$n.sims, 20))

for (i in 1:dat$n.sims) {
  for (j in 1:20) {
    Pstar1[i,j] <- 1 - (1 - mean(dat$sims.list[i,1, 1]))^j
    Pstar2[i,j] <- 1 - (1 - mean(dat$sims.list[i,2, 1]))^j
    Pstar3[i,j] <- 1 - (1 - mean(dat$sims.list[i,3, 1]))^j
    Pstar4[i,j] <- 1 - (1 - mean(dat$sims.list[i,4, 1]))^j
    Pstar5[i,j] <- 1 - (1 - mean(dat$sims.list[i,5, 1]))^j
    Pstar6[i,j] <- 1 - (1 - mean(dat$sims.list[i,6, 1]))^j
    Pstar7[i,j] <- 1 - (1 - mean(dat$sims.list[i,7, 1]))^j
    Pstar8[i,j] <- 1 - (1 - mean(dat$sims.list[i,8, 1]))^j
  } #j
} #i


# list all years together
ps = list(Pstar1, Pstar2, Pstar3, Pstar4,
          Pstar5, Pstar6, Pstar7, Pstar8)


nreps = 1000         # Note: 1000 replications

#################################
# one year only, up to 10 surveys
I_ran = matrix(nrow = 10, ncol = nreps) #creates 10x1000 matrix

for (i in 1:10) { #populates rows
  for(j in 1:nreps) { #populates columns
    I_ran[i,j] = colMeans(ps[[sample(1:8, 1)]])[1]  #each sample is the mean of the first column of a random year
  } #j
} #i

for (j in 2:10) { 
  I_ran[j,] = 1- ((1-I_ran[1,]) ^ j)
}

cis = matrix(nrow = 10, ncol = 2)

for(i in 1:10){
  cis[i,] = quantile(I_ran[i,], probs = c(.25, .75))
}

y = rowMedians(I_ran)


pdf("fig1.pdf", width = 8, height = 6)

par(mar = c(6,6,2,2), mfrow = c(1,1))

plot(1:10, y, type = "l", lwd = 2, ylim = c(0,1), xlim = c(0,10),
     main = "", xlab = "", ylab = "",
     cex.axis=1.5, cex.main = 1.5, cex = 2, axes = F)
lines(1:10, cis[,1], lty = "dashed", lwd = 2)
lines(1:10, cis[,2], lty = "dashed", lwd = 2)
axis(1, cex.axis = 1.5, at = c(1:10))
axis(2, cex.axis = 1.5, at = c(0,0.2,0.4,0.6,0.8, 1.0), las = 2)

# print the overall labels
mtext("Surveys", side = 1, outer = TRUE, line = -2, cex = 2)
mtext("Detection Probability", side = 2, outer = TRUE, las = 3, line = -2, cex = 2)

dev.off()



############################################################
#scenarios with 1,2,3,and 4 surveys per year, up to 10 years

I_ran1 = I_ran2 = I_ran3 = I_ran4 = matrix(nrow = nreps, ncol = 10)
temp1 = temp2 = temp3 = temp4 = matrix(nrow = nreps, ncol = 10)

for (i in 1:nreps) {
  I_ran1[i,1] <- temp1[i,1] <- 1 - (1 - dat$sims.list[sample(1:2700, 1),sample(1:8, 1), 1])
  for (j in 2:10) {
    temp1[i,j] <- 1 - (1 - dat$sims.list[sample(1:2700, 1),sample(1:8, 1), 1])
    I_ran1[i,j] <- 1 - prod(1 - temp1[i,1:j])
  } #j
  
} #i

cis1 = cis2 = cis3 = cis4 = matrix(nrow = 10, ncol = 2)
for(i in 1:10){
  cis1[i,] = quantile(I_ran1[,i], probs = c(.05, .95))
}

# two surveys per year
for (i in 1:nreps) {
  I_ran2[i,1] <- temp2[i,1] <- 1 - (1 - dat$sims.list[sample(1:2700, 1),sample(1:8, 1), 1])^2
  for (j in 2:10) {
    temp2[i,j] <- 1 - (1 - dat$sims.list[sample(1:2700, 1),sample(1:8, 1), 1])^2
    I_ran2[i,j] <- 1 - prod(1 - temp2[i,1:j])
  } #j
  
} #i

for(i in 1:10){
  cis2[i,] = quantile(I_ran2[,i], probs = c(.05, .95))
}


# three surveys per year
for (i in 1:nreps) {
  I_ran3[i,1] <- temp3[i,1] <- 1 - (1 - dat$sims.list[sample(1:2700, 1),sample(1:8, 1), 1])^3
  for (j in 2:10) {
    temp3[i,j] <- 1 - (1 - dat$sims.list[sample(1:2700, 1),sample(1:8, 1), 1])^3
    I_ran3[i,j] <- 1 - prod(1 - temp3[i,1:j])
  } #j
  
} #i

for(i in 1:10){
  cis3[i,] = quantile(I_ran3[,i], probs = c(.05, .95))
}

# four surveys per year
for (i in 1:nreps) {
  I_ran4[i,1] <- temp4[i,1] <- 1 - (1 - dat$sims.list[sample(1:2700, 1),sample(1:8, 1), 1])^4
  for (j in 2:10) {
    temp4[i,j] <- 1 - (1 - dat$sims.list[sample(1:2700, 1),sample(1:8, 1), 1])^4
    I_ran4[i,j] <- 1 - prod(1 - temp4[i,1:j])
  } #j
  
} #i

for(i in 1:10){
  cis4[i,] = quantile(I_ran4[,i], probs = c(.05, .95))
}


#------------------
# fig comparing survey effort with box and whiskers

plotsegraph <- function(loc, value, sterr, sterr1, wiskwidth, color = "grey", linewidth = 2) {
  
  w <- wiskwidth/2
  segments(y0 = loc, y1 = loc, x0 = sterr, x1 = sterr1, col = color, 
           lwd = linewidth)
  segments(y0 = loc - w, y1 = loc + w, x0 = sterr1, x1 = sterr1, 
           col = color, lwd = linewidth)  # upper whiskers
  segments(y0 = loc - w, y1 = loc + w, x0 = sterr, x1 = sterr, 
           col = color, lwd = linewidth)  # lower whiskers
}



pdf("fig2.pdf", width = 12, height = 8)

par(mfrow = c(2,2))
par(oma = c(6, 6, 0, 0)) # make room (i.e. the 4's) for the overall x and y axis titles
par(mar = c(2, 2, 3, 1)) # make the plots be closer together

# 1 dip per year
plot(1:10, colMeans(I_ran1), type = "l", lwd = 2, ylim = c(-.1,1), xlim = c(0,10),
     main = "1 dip per year", xlab = "", ylab = "",
     cex.axis=1.5, cex.main = 1.5, cex = 2, axes = F)
lines(1:10, cis1[,1], lty = "dashed", lwd = 2)
lines(1:10, cis1[,2], lty = "dashed", lwd = 2)
axis(1, cex.axis = 1.5, at = c(1:10))
axis(2, cex.axis = 1.5, at = c(0,0.2,0.4,0.6,0.8, 1.0), las = 2)

x <- approx(colMeans(I_ran1), 1:10, xout = 0.99)$y
ulim = approx(cis1[,1], 1:10, xout = 0.99)$y
llim = approx(cis1[,2], 1:10, xout = 0.99)$y

points(x, -0.075, cex = 1.5, lwd = 2, pch = 19)
plot.errbars <- plotsegraph(-0.075, x, ulim, llim, 0.03, color = "black")

# 2 dips per year
plot(1:10, colMeans(I_ran2), type = "l", lwd = 2, ylim = c(-.1,1), xlim = c(0,10),
     main = "2 dips per year", xlab = "", ylab = "",
     cex.axis=1.5, cex.main = 1.5, cex = 2, axes = F)
lines(1:10, cis2[,1], lty = "dashed", lwd = 2)
lines(1:10, cis2[,2], lty = "dashed", lwd = 2)
axis(1, cex.axis = 1.5, at = c(1:10))
axis(2, cex.axis = 1.5, at = c(0,0.2,0.4,0.6,0.8, 1.0), las = 2)

x <- approx(colMeans(I_ran2), 1:10, xout = 0.99)$y
ulim = approx(cis2[,1], 1:10, xout = 0.99)$y
llim = 1


points(x, -0.075, cex = 1.5, lwd = 2, pch = 19)
plot.errbars <- plotsegraph(-0.075, x, ulim, llim, 0.03, color = "black")


# 3 dips per year
plot(1:10, colMeans(I_ran3), type = "l", lwd = 2, ylim = c(-.1,1), xlim = c(0,10),
     main = "3 dips per year", xlab = "", ylab = "",
     cex.axis=1.5, cex.main = 1.5, cex = 2, axes = F)
lines(1:10, cis3[,1], lty = "dashed", lwd = 2)
lines(1:10, cis3[,2], lty = "dashed", lwd = 2)
axis(1, cex.axis = 1.5, at = c(1:10))
axis(2, cex.axis = 1.5, at = c(0,0.2,0.4,0.6,0.8, 1.0), las = 2)

x <- approx(colMeans(I_ran3), 1:10, xout = 0.99)$y
ulim = approx(cis3[,1], 1:10, xout = 0.99)$y
llim = 1

points(x, -0.075, cex = 1.5, lwd = 2, pch = 19)
plot.errbars <- plotsegraph(-0.075, x, ulim, llim, 0.03, color = "black")


# 4 dips per year
plot(1:10, colMeans(I_ran4), type = "l", lwd = 2, ylim = c(-.1,1), xlim = c(0,10),
     main = "4 dips per year", xlab = "", ylab = "",
     cex.axis=1.5, cex.main = 1.5, cex = 2, axes = F)
lines(1:10, cis4[,1], lty = "dashed", lwd = 2)
lines(1:10, cis4[,2], lty = "dashed", lwd = 2)
axis(1, cex.axis = 1.5, at = c(1:10))
axis(2, cex.axis = 1.5, at = c(0,0.2,0.4,0.6,0.8, 1.0), las = 2)

x <- approx(colMeans(I_ran4), 1:10, xout = 0.99)$y
ulim = approx(cis4[,1], 1:10, xout = 0.99)$y
llim = 1


points(x, -0.075, cex = 1.5, lwd = 2, pch = 19)
plot.errbars <- plotsegraph(-0.075, x, ulim, llim, 0.03, color = "black")

# print the overall labels
mtext("Number of Years", side = 1, outer = TRUE, line = 3, cex = 2)
mtext("Detection Probability", side = 2, outer = TRUE, las = 3, line = 3, cex = 2)


dev.off()

